# VideoRecordingPart


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**size** | **int** |  | 
**buffer_index** | **int** |  | 
**buffer_runningtime** | **int** |  | 
**file_name** | **str** |  | 
**mp4_file** | **str** |  | 
**sync_start** | **datetime** |  | 
**sync_end** | **datetime** |  | [readonly] 
**video_recording** | **str** |  | 
**user** | **int** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


